@@ -1,3 +1,24 @@
+##############################################################################
+#    Copyright (c) 2012-2016 Russell V. Lenth                                #
+#                                                                            #
+#    This file is part of the lsmeans package for R (*lsmeans*)              #
+#                                                                            #
+#    *lsmeans* is free software: you can redistribute it and/or modify       #
+#    it under the terms of the GNU General Public License as published by    #
+#    the Free Software Foundation, either version 2 of the License, or       #
+#    (at your option) any later version.                                     #
+#                                                                            #
+#    *lsmeans* is distributed in the hope that it will be useful,            #
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+#    GNU General Public License for more details.                            #
+#                                                                            #
+#    You should have received a copy of the GNU General Public License       #
+#    along with R and *lsmeans*.  If not, see                                #
+#    <https://www.r-project.org/Licenses/> and/or                            #
+#    <http://www.gnu.org/licenses/>.                                         #
+##############################################################################
+
 ### This file has summary.ref.grid S3 method and related functions
 
 # Computes the quadratic form y'Xy after subsetting for the nonzero elements of y
@@ -305,7 +326,10 @@
 ### Support for different prediction types ###
 
 # Valid values for type arg or predict.type option
-.valid.types = c("link","response","lp","linear")
+#   "link", "lp", "linear" are all legal but equivalent
+#   "mu" and "response" are usually equivalent -- but in a GLM with a response transformation,
+#      "mu" (or "unlink") would back-transform the link only, "response" would do both
+.valid.types = c("link","lp","linear", "response", "mu", "unlink")
 
 # get "predict.type" option from misc, and make sure it's legal
 .get.predict.type = function(misc) {
@@ -317,10 +341,12 @@
 }
 
 # check a "type" arg to make it legal
+# NOTE: if not matched, returns "link", i.e., no back-transformation will be done
 .validate.type = function (type) {
     .valid.types[pmatch(type, .valid.types, 1)]
 }
 
+
 # S3 predict method
 predict.ref.grid <- function(object, type, ...) {
     # update with any "summary" options
@@ -334,16 +360,21 @@ predict.ref.grid <- function(object, type, ...) {
         type = .get.predict.type(object@misc)
     else
         type = .validate.type(type)
+
+    # if there are two transformations and we want response, then we need to undo both
+    if ((type == "response") && (!is.null(object@misc$tran2)))
+            object = regrid(object, transform = "mu")
     
     pred = .est.se.df(object, do.se=FALSE)
     result = pred[[1]]
-    # MOVED TO .EST.SE.DF    
-    #     if (".offset." %in% names(object@grid))
-    #         result = result + object@grid[[".offset."]]
-    if (type == "response") {
+
+    if (type %in% c("response", "mu", "unlink")) {
         link = attr(pred, "link")
-        if (!is.null(link))
+        if (!is.null(link)) {
             result = link$linkinv(result)
+            if (is.logical(link$unknown) && link$unknown)
+                warning("Unknown transformation: \"", link$name, "\" -- no transformation applied.")
+        }
     }
     result
 }
@@ -366,6 +397,18 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
     else
         type = .validate.type(type)
     
+    if (!is.na(object@post.beta[1]))
+        message("This is a frequentist summary. See `?as.mcmc.ref.grid' for more on what you can do.")
+    
+    # if there are two transformations and we want response, then we need to undo both
+    if ((type == "response") && (!is.null(object@misc$tran2)))
+        object = regrid(object, transform = "mu")
+    if ((type %in% c("mu", "unlink")) && (!is.null(t2 <- object@misc$tran2))) {
+        if (!is.character(t2))
+            t2 = "tran"
+        object = update(object, inv.lbl = paste0(t2, "(resp)"))
+    }
+    
     if(missing(df)) 
         df = object@misc$df
     if(!is.null(df))
@@ -405,7 +448,7 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
     lbls = object@grid[lblnms]
     
     zFlag = (all(is.na(result$df)))
-    inv = (type == "response") # flag to inverse-transform
+    inv = (type %in% c("response", "mu", "unlink")) # flag to inverse-transform
     link = attr(result, "link")
     if (inv && is.null(link))
         inv = FALSE
@@ -419,7 +462,7 @@ summary.ref.grid <- function(object, infer, level, adjust, by, type, df,
         if (!is.null(object@misc$inv.lbl))
             names(result)[1] = object@misc$inv.lbl
         else
-            names(result)[1] = "lsresponse"
+            names(result)[1] = "response"
     }
 
     attr(result, "link") = NULL
